// Import tools
import { browseMessageTool } from './browser/browseMessage.js';
import { browseStartTool } from './browser/browseStart.js';
import { subAgentTool } from './interaction/subAgent.js';
import { userPromptTool } from './interaction/userPrompt.js';
import { fetchTool } from './io/fetch.js';
import { textEditorTool } from './io/textEditor.js';
import { createMcpTool } from './mcp.js';
import { listBackgroundToolsTool } from './system/listBackgroundTools.js';
import { sequenceCompleteTool } from './system/sequenceComplete.js';
import { shellMessageTool } from './system/shellMessage.js';
import { shellStartTool } from './system/shellStart.js';
import { sleepTool } from './system/sleep.js';
export function getTools(options) {
    const userPrompt = options?.userPrompt !== false; // Default to true if not specified
    const mcpConfig = options?.mcpConfig || { servers: [], defaultResources: [] };
    // Force cast to Tool type to avoid TypeScript issues
    const tools = [
        textEditorTool,
        subAgentTool,
        /*agentStartTool as unknown as Tool,
        agentMessageTool as unknown as Tool,*/
        sequenceCompleteTool,
        fetchTool,
        shellStartTool,
        shellMessageTool,
        browseStartTool,
        browseMessageTool,
        //respawnTool as unknown as Tool,  this is a confusing tool for now.
        sleepTool,
        listBackgroundToolsTool,
    ];
    // Only include userPrompt tool if enabled
    if (userPrompt) {
        tools.push(userPromptTool);
    }
    // Add MCP tool if we have any servers configured
    if (mcpConfig.servers && mcpConfig.servers.length > 0) {
        const mcpTool = createMcpTool(mcpConfig);
        tools.push(mcpTool);
    }
    return tools;
}
//# sourceMappingURL=getTools.js.map